@@ -1,6 +1,10 @@
 from jdTranslationHelper import jdTranslationHelper
 from jdMinecraftLauncher.Profile import Profile
 from jdMinecraftLauncher.Settings import Settings
+from jdMinecraftLauncher.Functions import showMessageBox
+from jdMinecraftLauncher import Crypto
+from cryptography.fernet import InvalidToken
+from PyQt5.QtWidgets import QInputDialog, QWidget
 from PyQt5.QtCore import QLocale
 from PyQt5.QtGui import QIcon
 import minecraft_launcher_lib
@@ -11,7 +15,7 @@ import os
 
 class Enviroment():
     def __init__(self):
-        self.launcherVersion = "2.0"
+        self.launcherVersion = "2.1"
         self.offlineMode = False
         self.currentDir = os.path.dirname(os.path.realpath(__file__))
 
@@ -39,15 +43,39 @@ class Enviroment():
                 data = json.load(f)
                 self.accountList = data.get("accountList",[])
                 self.selectedAccount = data.get("selectedAccount",0)
-                self.account = self.accountList[self.selectedAccount]
+                try:
+                    self.account = self.accountList[self.selectedAccount]
+                except IndexError:
+                    self.account = self.accountList[0]
+                    self.selectedAccount = 0
+
+        self.saved_passwords = {}
+        self.encrypt_password = ""
+        if os.path.isfile(os.path.join(self.dataPath,"jdMinecraftLauncher","saved_passwords.json")):
+            with open(os.path.join(self.dataPath,"jdMinecraftLauncher","saved_passwords.json"),"rb") as f:
+                self.encrypt_password, ok = QInputDialog.getText(QWidget(),self.translate("inputdialog.enterPassword.title"),self.translate("inputdialog.enterPassword.text"))
+                if ok:
+                    key = Crypto.get_key(self.encrypt_password)
+                    try:
+                        password_str = Crypto.decrypt(f.read(),key)
+                        self.saved_passwords = json.loads(password_str)
+                    except InvalidToken:
+                        showMessageBox("messagebox.wrongEncryptPassword.title","messagebox.wrongEncryptPassword.text",self)
+                        sys.exit(0)
 
         self.loadVersions()
 
         self.profiles = []
+        self.selectedProfile = 0
         if os.path.isfile(os.path.join(self.dataPath,"jdMinecraftLauncher","profiles.json")):
             with open(os.path.join(self.dataPath,"jdMinecraftLauncher","profiles.json")) as f:
                 data = json.load(f)
-            for i in data:
+                if isinstance(data,list):
+                    profileList = data
+                else:
+                    profileList = data["profileList"]
+                    self.selectedProfile = data["selectedProfile"]
+            for i in profileList:
                 p = Profile(i["name"],self)
                 p.load(i)
                 self.profiles.append(p)
